
:orphan:

Cold Spring Harbor Laboratory
=============================

Automatically generated index page for Cold Spring Harbor Laboratory:

.. raw:: html

   <ul>

   </ul>
     <a href="star_alignreads.html">
       <p style="margin-bottom: 5px"><b>STAR Aligner</b> <span style="margin-left: 10px; color: darkgray">star_alignReads</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(3 versions)</span><a class="version-button" href="star_alignreads.html" style="margin-bottom: 10px">
       v<b>2.7.5c</b>
     </a></p>
     </a>
     <hr />
         
     <a href="star_genomegenerate.html">
       <p style="margin-bottom: 5px"><b>STAR Aligner</b> <span style="margin-left: 10px; color: darkgray">star_genomeGenerate</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(3 versions)</span><a class="version-button" href="star_genomegenerate.html" style="margin-bottom: 10px">
       v<b>2.7.5c</b>
     </a></p>
     </a>
     <hr />
         
     <a href="star_inputalignmentsfrombam.html">
       <p style="margin-bottom: 5px"><b>STAR Aligner</b> <span style="margin-left: 10px; color: darkgray">star_inputAlignmentsFromBAM</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(3 versions)</span><a class="version-button" href="star_inputalignmentsfrombam.html" style="margin-bottom: 10px">
       v<b>2.7.5c</b>
     </a></p>
     </a>
     <hr />
         
     <a href="star_liftover.html">
       <p style="margin-bottom: 5px"><b>STAR Aligner</b> <span style="margin-left: 10px; color: darkgray">star_liftOver</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(3 versions)</span><a class="version-button" href="star_liftover.html" style="margin-bottom: 10px">
       v<b>2.7.5c</b>
     </a></p>
     </a>
     <hr />
         

